/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.cocoon.servlet.controller;

import java.util.Collections;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.cocoon.servlet.util.HttpContextHelper;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class ControllerContextHelper {

    private static final Log LOG = LogFactory.getLog(ControllerContextHelper.class);

    private static final String CONTEXT_OBJECT = ControllerContextHelper.class.getName();

    @SuppressWarnings("unchecked")
    public static Map<String, Object> getContext(Map<String, ? extends Object> parameters) {
        HttpServletRequest request = HttpContextHelper.getRequest(parameters);
        Object controllerContext = request.getAttribute(CONTEXT_OBJECT);

        if (controllerContext instanceof Map) {
            return (Map<String, Object>) controllerContext;
        }

        LOG.warn("The parameters contain an entry with the key " + CONTEXT_OBJECT + " but it is not a map.");
        return Collections.EMPTY_MAP;
    }

    public static void storeContext(Map<String, Object> controllerContext, Map<String, Object> parameters) {
        HttpServletRequest request = HttpContextHelper.getRequest(parameters);
        request.setAttribute(CONTEXT_OBJECT, controllerContext);
    }
}
